import pyshark  # Importuje knihovnu pyshark pro analýzu paketů
import time  # Importuje knihovnu time pro práci s časem

def get_unique_addresses(filename):
    with pyshark.FileCapture(filename, display_filter='btle') as cap:  # Otevře soubor .pcapng a filtruje pouze Bluetooth Low Energy (btle) pakety
        addresses = set()  # Inicializuje množinu pro ukládání unikátních adres
        start_time = None  # Inicializuje proměnnou pro ukládání času prvního paketu
        for pkt in cap:  # Prochází všechny pakety v souboru
            if start_time is None:  # Pokud je to první paket, uloží jeho čas
                start_time = pkt.sniff_time.timestamp()
            elif pkt.sniff_time.timestamp() - start_time > 7200:  # Pokud od prvního paketu uplynulo více než 7200 vteřin (2 hodiny), přeruší se cyklus
                break
            if hasattr(pkt, 'btle'):  # Pokud paket obsahuje Bluetooth Low Energy data
                addresses.add(pkt.btle.advertising_header)  # Přidá adresu do množiny
        return addresses  # Vrátí množinu adres

def main():
    # Cesty k souborům .pcapng...pro jiný počítač a uživatele budou odlišné!
    file1 = r'C:\Users\schar\Desktop\BP\Zachytavani_TC\TC_sniff_test_07022024.pcapng'
    file2 = r'C:\Users\schar\Desktop\BP\Zachytavani_TC\TC_sniff_test_14022024.pcapng'

    addresses1 = get_unique_addresses(file1)  # Získá unikátní adresy z prvního souboru
    addresses2 = get_unique_addresses(file2)  # Získá unikátní adresy z druhého souboru

    # Vypíše počet unikátních adres z obou souborů
    print(f'Počet unikátních adres z 7.2.2024: {len(addresses1)}')
    print(f'Počet unikátních adres z 14.2.2024: {len(addresses2)}')

    common_addresses = addresses1.intersection(addresses2)  # Získá adresy, které se vyskytují v obou souborech
    print(f'Počet stejných adres v obou souborech: {len(common_addresses)}')  # a vypíše jejich počet

if __name__ == '__main__':
    main()  # Spustí hlavní funkci
