import pyshark  # Importuje knihovnu pyshark pro analýzu paketů
import time  # Importuje knihovnu time pro práci s časem

def get_unique_addresses(filename):
    addresses = set()  # Inicializuje množinu pro ukládání unikátních adres
    start_time = None  # Inicializuje proměnnou pro ukládání počátečního času
    with pyshark.FileCapture(filename, display_filter='btle') as cap:  # Otevře soubor a filtruje pakety BLE
        for pkt in cap:  # Prochází všechny pakety v souboru
            if start_time is None:
                start_time = float(pkt.frame_info.time_epoch)  # Uloží počáteční čas

            if float(pkt.frame_info.time_epoch) - start_time > 25:  # Pokud uplynulo více než 25 sekund, ukončí cyklus
                break

            if hasattr(pkt, 'btle'):  # Pokud paket má atribut 'btle'
                addresses.add(pkt.btle.advertising_header)  # Přidá jeho 'advertising_header' do množiny adres
    return addresses  # Vrátí množinu adres

def main():
    # Seznam souborů pro analýzu
    files = [r'C:\Users\schar\Desktop\BP\Konstantnost_adres_test\15_15.pcapng', r'C:\Users\schar\Desktop\BP\Konstantnost_adres_test\16_15.pcapng', r'C:\Users\schar\Desktop\BP\Konstantnost_adres_test\17_15.pcapng', r'C:\Users\schar\Desktop\BP\Konstantnost_adres_test\18_15.pcapng', r'C:\Users\schar\Desktop\BP\Konstantnost_adres_test\19_15.pcapng', r'C:\Users\schar\Desktop\BP\Konstantnost_adres_test\20_15.pcapng']
    addresses_list = []  # Seznam pro ukládání množin adres z jednotlivých souborů
    total_addresses = set()  # Množina pro ukládání všech adres

    for file in files:  # Prochází všechny soubory
        addresses = get_unique_addresses(file)  # Získá unikátní adresy z aktuálního souboru
        addresses_list.append(addresses)  # Přidá množinu adres do seznamu
        total_addresses.update(addresses)  # Přidá adresy do celkové množiny adres
        print(f'Počet unikátních adres v {file}: {len(addresses)}')  # Vypíše počet unikátních adres v aktuálním souboru

    common_addresses = set.intersection(*addresses_list)  # Získá adresy, které se nachází ve všech souborech
    print(f'Počet unikátních adres v obou souborech: {len(common_addresses)}')  # Vypíše počet těchto adres
    print(f'Celkový počet unikátních adres ve všech souborech: {len(total_addresses)}')  # Vypíše celkový počet unikátních adres

if __name__ == '__main__':
    main()  # Spustí hlavní funkci